pub struct Preedit {
text: String,
cursor_byte_offset: Option<(usize, usize)>,
cursor_end_offset: Option<(usize, usize)>,
}Fields
text: StringThe preedit text.
cursor_byte_offset: Option<(usize, usize)>Byte offset for cursor start into the preedit text.
None means that the cursor is invisible.
cursor_end_offset: Option<(usize, usize)>The cursor offset from the end of the start of the preedit in char width.
Implementations